function display_MRI(im, x, y, z, whichData)
% display_MRI(im, x, y, z, whichData)
% given an input 3D MRI volume im (anatomical or functional), displays
% the coronal, sagittal, and horizontal slices that intersect at voxel 
% location (x, y, z). The input whichData indicates whether the data is 
% anatomical (0) or functional (1)
    
figure('units','normalized','position',[0 0 1 1]);

value = im(x,y,z);
if whichData
    im = 0.9*im;
    pos = 0.5;
else
    pos = 1.5;
end

coronalIm = flip(permute(im,[3,2,1]),1);    % coronal slice
slice = coronalIm(:,:,x);
subplot(2,2,1)
imagesc(slice)
colormap gray
hold on
plot(y,size(slice,1)+1-z,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-z size(slice,1)+1-z], '--r', 'linewidth', 2);
plot([y y], [0 size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([pos size(slice,2)+0.5 size(slice,2)+0.5 pos pos], ...
    [pos pos size(slice,1)+0.5 size(slice,1)+0.5 pos], '-b', 'linewidth', 3)
text(size(slice,2)/2, 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Coronal Slice', 'fontsize', 20, 'fontweight','bold', 'color','b');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

sagittalIm = flip(permute(im,[3,1,2]),1);	%  sagittal slice
slice = sagittalIm(:,:,y);
subplot(2,2,2)
imagesc(slice)
colormap gray
hold on
plot(x,size(slice,1)+1-z,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-z size(slice,1)+1-z], '--r', 'linewidth', 2);
plot([x x], [0 size(slice,1)], '--b', 'linewidth', 2);
plot([pos size(slice,2)+0.5 size(slice,2)+0.5 pos pos], ...
    [pos pos size(slice,1)+0.5 size(slice,1)+0.5 pos], '-', 'color', [0 0.7 0], 'linewidth', 3)
text(size(slice,2)/2, 4, 'Top', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Bottom', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Sagittal Slice', 'fontsize', 20, 'fontweight','bold', 'color',[0 0.7 0]);
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

slice = flip(im(:,:,z),1);          % horizontal slice
subplot(2,2,3)	
imagesc(slice);
colormap gray
hold on
plot(y,size(slice,1)+1-x,'ow','markersize',16,'linewidth',2);
plot([0 size(slice,2)], [size(slice,1)+1-x size(slice,1)+1-x], '--b', 'linewidth', 2);
plot([y y], [0 size(slice,1)], '--', 'color', [0 0.7 0], 'linewidth', 2);
plot([pos size(slice,2)+0.5 size(slice,2)+0.5 pos pos], ...
    [pos pos size(slice,1)+0.5 size(slice,1)+0.5 pos], '-r', 'linewidth', 3)
text(size(slice,2)/2, 4, 'Front', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
text(size(slice,2)/2, size(slice,1)-3, 'Back', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
text(4, size(slice,1)/2, 'Right', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top');
text(size(slice,2)-4, size(slice,1)/2, 'Left', ...
    'fontsize', 16, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
title('Horizontal Slice', 'fontsize', 20, 'fontweight','bold', 'color','r');
pbaspect([1, size(slice,1)/size(slice,2), 1]);
axis off

subplot(2,2,4)
set(gca,'xlim',[0 10],'ylim',[0 10]);
text(5,5,{'The voxel you accessed';'(circled in white)';['has a value of ', num2str(value)]},...
'fontsize',24,'horizontalalignment','center','verticalalignment','middle');
axis off