function display_final_output(tVals)
% display_final_output(tVals)
% displays the final results of the fMRI analysis, with the locations of
% significant t-values shown in color, superimposed on anatomical MRI data.
% results displayed for 9 distinct sagittal brain slices - the location
% of each slice is indicated in the title above the image. A blue circle
% on each image marks a voxel location for the user to examine. 

figure

load finalDisplayInfo
df = 189-size(Q_Final.X,2); % 189 is the number of TRs in func
t_crit = tinv(0.999,df);    % p = 0.001, uncorrected
tVals(tVals<=t_crit) = t_crit;         % values go from t_ctic up
tVals = tVals - min(tVals(:));         % values go from 0 up
tVals = (tVals/max(tVals(:)))*(41/63); % for the colormap, values go from 0 to 41/63;

voxels = find(tVals > 0);
T1_tVals = zeros(size(Q_Final.T1));
T1_dims = size(T1_tVals);
for ii = 1:numel(voxels)
    [x,y,z] = ind2sub(size(tVals),voxels(ii));
    RAS_coords = Q_Final.func_to_ras*[y;x;z;1];
    T1_coords = (inv(Q_Final.anat_to_ras))*RAS_coords;      % returns [y;x;z;1]
    T1_coords = round(T1_coords([2 1 3]));                  
    T1_coords(2) = y;
    for x_i = -1:1
        for z_i = -1:1
            xyz = [T1_coords(1)+x_i, T1_coords(2), T1_coords(3)+z_i];                
            if all(xyz>0) && all(xyz<=T1_dims)
                T1_tVals(xyz(1), xyz(2), xyz(3)) = tVals(x,y,z);
            end
        end
    end
end
T1_final = Q_Final.T1;
T1_final(T1_tVals>0) = 1+T1_tVals(T1_tVals>0);  % values below 1 are the anatomical image, values above 1 are t-scores
clear T1_tVals voxels;
T1_final = flip(permute(T1_final, [3,1,2]));    % now the 3rd dimension is saggital slices

c1 = colormap('gray');  % colormap for anatomical image
c1 = c1(1:(end-1),:);   % not including white
c2 = colormap('hot');   % colormap for significant t-values
c2 = c2(24:end,:);      % from red to white
c = [c1;c2];

tMax = max(T1_final(:));
for ii = 1:size(Q_Final.keyVoxels_T1,1)
    if mod(ii,4) == 1
        % figure((ii+3)/4)
        figure
    end
    subplot(2,2,mod(ii-1,4)+1)
    colormap(c)

    x = Q_Final.keyVoxels_T1(ii,1);
    z = Q_Final.keyVoxels_T1(ii,3);
    sliceInd = Q_Final.T1UniqueSaggitalSlices == Q_Final.keyVoxels_T1(ii,2);
    imagesc(T1_final(:,:,sliceInd));
    caxis([0 tMax]);
    hold on
    
    plot(x,size(T1_final,1)+1-z,'ob','markersize',8,'linewidth',2);
    text(5,10,num2str(ii),'color',[0.3 0.3 1],'fontsize',12);

    text(size(T1_final,2)/2, 4, 'Top', ...
        'fontsize', 12, 'fontweight', 'bold', 'color', 'w', 'verticalalignment','top', 'horizontalalignment','center');
    text(size(T1_final,2)/2, size(T1_final,1)-3, 'Bottom', ...
        'fontsize', 12, 'fontweight', 'bold', 'color', 'w', 'verticalalignment', 'bottom', 'horizontalalignment','center');
    text(4, size(T1_final,1)/2, 'Back', ...
        'fontsize', 12, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'left', 'verticalalignment', 'top'); 
    text(size(T1_final,2)-4, size(T1_final,1)/2, 'Front', ...
        'fontsize', 12, 'fontweight', 'bold', 'color', 'w', 'horizontalalignment', 'right', 'verticalalignment', 'top');
    axis off
    
    if Q_Final.keyVoxels_RAS(ii,1) < 0
        title(['Left hemisphere, ', num2str(Q_Final.keyVoxels_RAS(ii,1)), ' mm'], 'fontsize', 12);
    else
        title(['Right hemisphere, ', num2str(Q_Final.keyVoxels_RAS(ii,1)), ' mm'], 'fontsize', 12);
    end
end